
From: Nishanth Aravamudan <nacc@us.ibm.com>

Add a usecs_to_jiffies() function.  This will be used in one of my
subsequent patches.  With the potential for dynamic HZ values much higher
than 1000, we may need to consider times as small as usecs in terms of
jiffies.  We have msecs_to_jiffies(), jiffies_to_msecs() and
jiffies_to_usecs(), but no usecs_to_jiffies().

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/jiffies.h |   13 +++++++++++++
 1 files changed, 13 insertions(+)

diff -puN include/linux/jiffies.h~add-a-usecs_to_jiffies-function include/linux/jiffies.h
--- 25/include/linux/jiffies.h~add-a-usecs_to_jiffies-function	2005-01-26 17:22:54.478641800 -0800
+++ 25-akpm/include/linux/jiffies.h	2005-01-26 17:22:54.482641192 -0800
@@ -287,6 +287,19 @@ static inline unsigned long msecs_to_jif
 #endif
 }
 
+static inline unsigned long usecs_to_jiffies(const unsigned int u)
+{
+	if (u > jiffies_to_usecs(MAX_JIFFY_OFFSET))
+		return MAX_JIFFY_OFFSET;
+#if HZ <= 1000 && !(1000 % HZ)
+	return (u + (1000000 / HZ) - 1000) / (1000000 / HZ);
+#elif HZ > 1000 && !(HZ % 1000)
+	return u * (HZ / 1000000);
+#else
+	return (u * HZ + 999999) / 1000000;
+#endif
+}
+
 /*
  * The TICK_NSEC - 1 rounds up the value to the next resolution.  Note
  * that a remainder subtract here would not do the right thing as the
_
